package com.ztmap.project.zhny.netfdswl.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.netfdswl.mapper.TNetFdswlMapper;
import com.ztmap.project.zhny.netfdswl.domain.TNetFdswl;
import com.ztmap.project.zhny.netfdswl.service.ITNetFdswlService;
import com.ztmap.common.utils.text.Convert;

/**
 * 风电上网量Service业务层处理
 * 
 * @author ztmap
 * @date 2023-11-16
 */
@Service
public class TNetFdswlServiceImpl implements ITNetFdswlService 
{
    @Autowired
    private TNetFdswlMapper tNetFdswlMapper;

    /**
     * 查询风电上网量
     * 
     * @param id 风电上网量ID
     * @return 风电上网量
     */
    @Override
    public TNetFdswl selectTNetFdswlById(Long id)
    {
        return tNetFdswlMapper.selectTNetFdswlById(id);
    }

    /**
     * 查询风电上网量列表
     * 
     * @param tNetFdswl 风电上网量
     * @return 风电上网量
     */
    @Override
    public List<TNetFdswl> selectTNetFdswlList(TNetFdswl tNetFdswl)
    {
        return tNetFdswlMapper.selectTNetFdswlList(tNetFdswl);
    }

    /**
     * 新增风电上网量
     * 
     * @param tNetFdswl 风电上网量
     * @return 结果
     */
    @Override
    public int insertTNetFdswl(TNetFdswl tNetFdswl)
    {
        return tNetFdswlMapper.insertTNetFdswl(tNetFdswl);
    }

    /**
     * 修改风电上网量
     * 
     * @param tNetFdswl 风电上网量
     * @return 结果
     */
    @Override
    public int updateTNetFdswl(TNetFdswl tNetFdswl)
    {
        return tNetFdswlMapper.updateTNetFdswl(tNetFdswl);
    }

    /**
     * 删除风电上网量对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTNetFdswlByIds(String ids)
    {
        return tNetFdswlMapper.deleteTNetFdswlByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除风电上网量信息
     * 
     * @param id 风电上网量ID
     * @return 结果
     */
    @Override
    public int deleteTNetFdswlById(Long id)
    {
        return tNetFdswlMapper.deleteTNetFdswlById(id);
    }
}
